@@ -47,7 +47,7 @@ func NewGitLab(ctx *context.Context, token string) (Client, error) {
 
 	var client *gitlab.Client
 	var err error
-	if ctx.Config.GitLabURLs.UseJobToken {
+	if checkUseJobToken(*ctx, token) {
 		client, err = gitlab.NewJobClient(token, options...)
 	} else {
 		client, err = gitlab.NewClient(token, options...)
@@ -495,3 +495,24 @@ func (c *gitlabClient) getMilestoneByTitle(repo Repo, title string) (*gitlab.Mil
 
 	return nil, nil
 }
+
+// checkUseJobToken examines the context and given token, and determines if We should use NewJobClient vs NewClient
+func checkUseJobToken(ctx context.Context, token string) bool {
+	// The CI_JOB_TOKEN env var is set automatically in all GitLab runners.
+	// If this comes back as empty, we aren't in a functional GitLab runner
+	ciToken := os.Getenv("CI_JOB_TOKEN")
+	if ciToken == "" {
+		return false
+	}
+
+	// We only want to use the JobToken client if we have specified
+	// UseJobToken. Older versions of GitLab don't work with this, so we
+	// want to be specific
+	if ctx.Config.GitLabURLs.UseJobToken {
+		// We may be creating a new client with a non-CI_JOB_TOKEN, for
+		// things like Homebrew publishing. We can't use the
+		// CI_JOB_TOKEN there
+		return token == ciToken
+	}
+	return false
+}
